:og:description: The API documentation for Mantelo.

.. meta::
   :description: The API documentation for Mantelo.

.. _api:

The API Documentation
=====================

.. toctree::
    :maxdepth: 2

    reference/mantelo/index
